==> maven-common-artifact-filters_3.3.2.orig.tar.xz: maven-common-artifact-filters-maven-common-artifact-filters-3.3.2/src/main/java/org/apache/maven/shared/artifact/filter/collection/ClassifierFilter.java <==
package org.apache.maven.shared.artifact.filter.collection;

/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */

import org.apache.maven.artifact.Artifact;

/**
 * <p>ClassifierFilter class.</p>
 *
 * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
 */
public class ClassifierFilter
    extends AbstractArtifactFeatureFilter
{
    /**
     * <p>Constructor for ClassifierFilter.</p>
     *
     * @param include comma separated list with includes.
     * @param exclude comma separated list with excludes.
     */
    public ClassifierFilter( String include, String exclude )
    {
        super( include, exclude );
    }

    /** {@inheritDoc} */
    protected String getArtifactFeature( Artifact artifact )
    {
        return artifact.getClassifier();
    }
}

==> maven-common-artifact-filters_3.4.0.orig.tar.xz: maven-common-artifact-filters-maven-common-artifact-filters-3.4.0/src/main/java/org/apache/maven/shared/artifact/filter/collection/ClassifierFilter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.shared.artifact.filter.collection;

import org.apache.maven.artifact.Artifact;

/**
 * <p>ClassifierFilter class.</p>
 *
 * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
 */
public class ClassifierFilter extends AbstractArtifactFeatureFilter {
    /**
     * <p>Constructor for ClassifierFilter.</p>
     *
     * @param include comma separated list with includes.
     * @param exclude comma separated list with excludes.
     */
    public ClassifierFilter(String include, String exclude) {
        super(include, exclude);
    }

    /** {@inheritDoc} */
    protected String getArtifactFeature(Artifact artifact) {
        return artifact.getClassifier();
    }
}
